library(tidyverse)


# Prepare Data for Analysis -----------------------------------------------

cars <- mpg %>% 
  select(make = manufacturer, model, year, displ, cyl, class, hwy, cty) %>% 
  filter(cyl != 5) %>% 
  mutate(cyl = factor(cyl), class = factor(class))


# Scales ------------------------------------------------------------------

ggplot(mpg, aes(x = cty, y = hwy, color = displ)) +
  labs(color = "Displacement") +
  scale_color_viridis_c() +
  geom_point() + theme(text = element_text(size = 20), legend.position = "top")
ggsave("scale_color_continuous.png", width = 6, height = 5, units = "in")

ggplot(filter(mpg, cyl != 5), aes(x = cty, y = hwy, shape = factor(cyl))) +
  labs(shape = "Cylinders") +
  geom_point(size = 2) + theme(text = element_text(size = 20), legend.position = "top")
ggsave("scale_shape_discrete.png", width = 6, height = 5, units = "in")

ggplot(mpg, aes(x = cty, y = hwy, size = displ)) +
  labs(size = "Displacement") +
  scale_size_continuous(breaks = c(2, 4.5, 7)) +
  geom_point() + theme(text = element_text(size = 20), legend.position = "top")
ggsave("scale_size_continuous.png", width = 6, height = 5, units = "in")


# Statistical Transformation ----------------------------------------------
dat <- mpg %>% 
  mutate(class = fct_reorder(factor(class), hwy, .fun = mean))
ggplot(dat, aes(x = class, y = hwy, fill = class)) +
  geom_bar(stat = "summary", fun.y = "mean") +
  geom_errorbar(stat = "summary", fun.data = "mean_cl_boot", width = 0.2) +
  scale_x_discrete(name = "Class") +
  scale_y_continuous(name = "Highway (mpg)") +
  theme(
    text = element_text(size = 20), 
    axis.text.x = element_text(size = 14, angle = 45, hjust = 1, vjust = 1),
    legend.position = "none"
  )
ggsave("stat_summary.png", width = 6, height = 5, units = "in")

# Coordinate System -------------------------------------------------------

ggplot(mpg, aes(x = cty, y = hwy, color = factor(class))) +
  geom_jitter(size = 2) +
  scale_x_continuous(name = "City (mpg)", limits = c(5, 45)) +
  scale_y_continuous(name = "Highway (mpg)", limits = c(5, 45)) +
  labs(color = "Class") +
  theme(text = element_text(size = 20))
ggsave("coord_cartesian.png", width = 6, height = 5, units = "in")

ggplot(mpg, aes(x = cty, y = hwy, color = factor(class))) +
  geom_jitter(size = 2) +
  scale_x_continuous(name = "City (mpg)", limits = c(5, 45)) +
  scale_y_continuous(name = "Highway (mpg)", limits = c(5, 45)) +
  labs(color = "Class") +
  coord_equal() +
  theme(text = element_text(size = 20))
ggsave("coord_fixed.png", width = 6, height = 5, units = "in")

ggplot(mpg, aes(x = cty, y = hwy, color = factor(class))) +
  geom_jitter(size = 2) +
  scale_x_continuous(name = "City (mpg)", limits = c(5, 45)) +
  scale_y_continuous(name = "Highway (mpg)", limits = c(5, 45)) +
  labs(color = "Class") +
  coord_trans(x = "log10", y = "log10") +
  theme(text = element_text(size = 20))
ggsave("coord_trans.png", width = 6, height = 5, units = "in")

# Faceting Specification --------------------------------------------------

faceting <- ggplot(mpg, aes(x = displ, y = hwy)) +
  geom_point(size = 1.5) +
  geom_smooth(method = "lm") +
  facet_wrap(~class) +
  labs(x = "Displacement (L)", y = "Highway (mpg)") +
  theme(text = element_text(size = 20))
ggsave("faceting.png", width = 6, height = 5, units = "in")


# Theme -------------------------------------------------------------------

themed <- faceting + theme_bw() + theme(text = element_text(size = 20))
ggsave("themed.png", width = 6, height = 5, units = "in")

themed <- faceting + theme_dark() + theme(text = element_text(size = 20))
ggsave("themed2.png", width = 6, height = 5, units = "in")

# Building Figure 1: Basics -----------------------------------------------

fig1a <- ggplot(data = cars) +
  theme(text = element_text(size = 20))
ggsave("fig1a.png", width = 6, height = 5, units = "in")

cheat <- tibble(displ = rep(-10, 3), hwy = rep(-10, 3), cyl = factor(c(4, 6, 8)))

fig1b <- ggplot(data = cheat, aes(x = displ, y = hwy, color = cyl)) +
  geom_point(size = 2) +
  coord_cartesian(xlim = c(1, 7), ylim = c(5, 45)) +
  theme(text = element_text(size = 20))
ggsave("fig1b.png", width = 6, height = 5, units = "in")

fig1c <- ggplot(data = cheat, aes(x = displ, y = hwy, color = factor(cyl))) +
  geom_point(size = 2) +
  coord_cartesian(xlim = c(0, 8), ylim = c(0, 50)) +
  labs(x = "Displacement (L)", y = "Highway (mpg)", color = "Cylinders") +
  theme(text = element_text(size = 20))
ggsave("fig1c.png", width = 6, height = 5, units = "in")

fig1d <- fig1a %+%
  aes(x = displ, y = hwy, color = cyl) +
  geom_point(
    shape = "circle",
    size = 2
  ) +
  scale_x_continuous(limits = c(0, 8)) +
  scale_y_continuous(limits = c(0, 50)) +
  labs(x = "Displacement (L)", y = "Highway (mpg)", color = "Cylinders")
ggsave("fig1d.png", width = 6, height = 5, units = "in")

fig1e <- fig1d + 
  geom_smooth(
    method = "lm",
    se = TRUE
  )
ggsave("fig1e.png", width = 6, height = 5, units = "in")

fig1f <- fig1e +
  theme_bw() +
  theme(legend.position = "top", text = element_text(size = 20))
ggsave("fig1f.png", width = 6, height = 5, units = "in")



# Building Figure 2: Advanced ---------------------------------------------

fig2a <- ggplot(
  data = mpg, 
  mapping = aes(x = factor(cyl))
) %+%
  subset(mpg, cyl != 5) +
  geom_bar(stat = "count") +
  theme(text = element_text(size = 20))
ggsave("fig2a.png", width = 6, height = 5, units = "in")

fig2b <- ggplot(
  data = mpg,
  mapping = aes(x = factor(cyl), y = hwy)
) %+%
  subset(mpg, cyl != 5) + 
  geom_bar(
    stat = "summary", 
    fun.y = "mean"
  ) +
  labs(y = "mean(hwy)") +
  theme(text = element_text(size = 20))
ggsave("fig2b.png", width = 6, height = 5, units = "in")

fig2c <- fig2b +
  geom_errorbar(
    stat = "summary",
    fun.data = "mean_cl_boot",
    width = 0.25
  ) +
  scale_x_discrete(
    name = "Cylinders"
  ) +
  scale_y_continuous(
    name = "Mean Highway (mpg)"
  )
ggsave("fig2c.png", width = 6, height = 5, units = "in")

fig2d <- ggplot(
  data = mpg,
  mapping = aes(x = factor(cyl), y = hwy)
) %+%
  subset(mpg, cyl != 5) +
  geom_violin() +
  geom_jitter() +
  theme(text = element_text(size = 20))
ggsave("fig2d.png", width = 6, height = 5, units = "in")

fig2e <- fig2d +
  geom_point(
    stat = "summary", 
    fun.y = "median", 
    color = "red", 
    size = 6, 
    alpha = .75
  )
ggsave("fig2e.png", width = 6, height = 5, units = "in")

fig2f <- fig2e %+%
  aes(x = 1) +
  facet_wrap(~ factor(cyl)) +
  scale_x_discrete(position = "top") +
  labs(x = "Cylinders", y = "Highway (mpg)")
ggsave("fig2f.png", width = 6, height = 5, units = "in")
